/* STM32F373xC linker-script */

MEMORY
{
	FLASH(rx)	: ORIGIN = 0x08000000, LENGTH = 256K
	SRAM(xrw)	: ORIGIN = 0x20000000, LENGTH = 32K
	ERROR(w)	: ORIGIN = 0xBADF00D0, LENGTH = 0
}

__stack_init = ORIGIN(SRAM) + LENGTH(SRAM);	/* For vectors_%DEVSRC%_gas.s */

SECTIONS
{
	.text :							/* Assume FLASH origin is ALIGN(4) */
	{
		KEEP(*(.text.vect))			/* Interrupt vector table must be first */

		*(.text .text.*)			/* Code; assume .text.vect keeps ALIGN(4) */

		*(.rodata .rodata.*)		/* Read-only data (constants) */

		. = ALIGN(4);				/* Ensure align of LOADADDR(.data) */
	} >FLASH

	__text_end = LOADADDR(.data);	/* Definition used in crt_init.h */

	.bss :							/* Assume SRAM origin is ALIGN(4) */
	{
		__bss_start = .;			/* Definition used in crt_init.h */

		*(.bss .bss.*)				/* Uninitialized data */

		*(COMMON)

	} >SRAM

	.data BLOCK(4) :
	{
		__data_start = .;			/* Definition used in crt_init.h */

		*(.data .data.*)			/* Initialized data */

		__data_end = ALIGN(4);		/* Definition used in crt_init.h */
		PROVIDE (end = .);
	} >SRAM AT >FLASH

	/DISCARD/ :						/* Needed for LLVM 3.5.0 */
	{
		*(.ARM.exidx.*)
	}

	/* Preserve these expected sections in .elf but don't include in flash image */
	.comment 0 :		{ *(.comment) }/* Assembler .ident and likewise compiler */
	.debug_aranges 0 :	{ *(.debug_aranges) }			/* DWARF 1.1 and DWARF 2 */
	.debug_pubnames 0 : { *(.debug_pubnames) }
	.debug_pubtypes 0 : { *(.debug_pubtypes) }
	.debug_info 0 :		{ *(.debug_info .gnu.linkonce.wi.*) }		  /* DWARF 2 */
	.debug_abbrev 0 :	{ *(.debug_abbrev) }
	.debug_frame 0 :	{ *(.debug_frame) }
	.debug_line 0 :		{ *(.debug_line) }
	.debug_loc 0 :		{ *(.debug_loc) }
	.debug_ranges 0 :	{ *(.debug_ranges) }
	.debug_str 0 :		{ *(.debug_str) }
	.debug_macinfo 0 :	{ *(.debug_macinfo) }
	.ARM.attributes 0 : { *(.ARM.attributes) }			/* Program header info */
	.note.gnu.build-id :{ *(.note.gnu.build-id) }

	/* Any sections that are unspecified and non-empty will generate an error */
	.error : 			{ *(*) } > ERROR
}
